Type Alias js_sandbox::AnyError
source · pub type AnyError = AnyError;Expand description
Polymorphic error type able to represent different error domains.
Currently reusing anyhow::Error, this type may change slightly in the future depending on js-sandbox’s needs.
Aliased Type
struct AnyError { /* private fields */ }